## 2.0.4 - Released on 2024-10-30

* Try to publish using Trusted Publisher 


## 2.0.1 - Released on 2024-10-30

* Use uv and pdm instead of poetry 


## 2.0.0 - Release on 2024-10-19

* Drop python3.7
* Upgrade to celery-yaml 2

## 1.0.0 - Release on 2023-10-18

* Initial Release
